lens.summarise API
==================

.. currentmodule:: lens.summarise

.. automodule:: lens.summarise

.. autofunction:: lens.summarise.summarise

.. autoclass:: lens.summarise.Summary
   :members:

